import {
    request
} from '../selfRequest';


// 查询故障分类列表
export function deviceTypeListRq() {
    return request({
        url: '/repairDeviceApi/deviceTypeList',
        method: "get",
    });
}

// 根据故障分类查询故障设备列表
export function deviceListRq(data) {
    return request({
        url: '/repairDeviceApi/deviceList',
        method: "get",
        data
    });
}

// 查询地区
export function selectAddressListRq() {
    return request({
        url: '/repairDeviceApi/selectAddressList',
        method: "get",
    });
}

// 查询楼层
export function selectRoomListRq(data) {
    return request({
        url: '/repairDeviceApi/selectFloorList',
        method: "get",
        data
    });
}

// 保存工单
export function repairSaveRq(data) {
    return request({
        url: '/app/repair/flow/start',
        method: "post",
        data
    });
}

/**
 * 工单列表
 * menu:1.报修查询，3派单入口，5维修入口, 7 管理员,9 楼层管理员
 * <p>
 * 报修查询：全部、处理中、待评价、已评价、无效申请   type对应值：all、process、evaling、evaled、invalid
 * 派单入口：重新派单、待派单、已派单、已关闭（无效申请）  type对应值：anew、wait、already、close
 * 维修入口：待完成、进行中、已完成  type对应值：wait、working、close
 * 管理员：重派单，全部，无效申请    type对应值：anew、all、invalid  【小程序暂时用不到】
 * 楼层管理员：全部、无效申请  type对应值：all、invalid
 *
 * name : 工单名称搜索关键字
 * </p >
 */
export function repairListRq(data) {
    return request({
        url: `/app/repair/list?pageNum=${data.pageNum}&pageSize=${data.pageSize}`,
        method: "post",
        data
    });
}

// 获取详情
export function getDetailRq(data) {
    return request({
        url: `/app/repair/get`,
        method: "post",
        data
    });
}

// 流程处理
export function flowHandleRq(data) {
    return request({
        url: `/app/repair/flow/handle`,
        method: "post",
        data
    });
}

// 根据设备类型查询维修人员
export function selectWorkerIdByTypeIdRq(id) {
    return request({
        url: `/repairDeviceApi/selectWorkerIdByTypeId?typeId=${id}`,
        method: "get",
    });
}

// 获取维修人员工单数量统计
export function workerRepairNumberRq(id) {
    return request({
        url: `/app/repair/workerRepairNumber`,
        method: "post",
    });
}


// 故障原因-字典
export function faultTypeListRq() {
    return request({
        url: `/repairDeviceApi/faultTypeList`,
        method: "get",
    });
}

// 评价
export function repairEvalRq(data) {
    return request({
        url: `/app/repair/eval`,
        method: "post",
        data
    });
}

// 消息未读列表
export function repairRemindLatestListRq() {
    return request({
        url: `/app/repairRemind/latestList`,
        method: "get",
    });
}

// 消息提醒列表
export function repairRemindListRq(data) {
    return request({
        url: `/app/repairRemind/list`,
        method: "get",
        data
    });
}

// 消息提醒已读
export function repairRemindReadRq(data) {
    return request({
        url: `/app/repairRemind/read`,
        method: "post",
        data
    });
}

// 删除指定id消息
export function repairRemindRemoveRq(data) {
  return request({
      url: `/app/repairRemind/batchRemove`,
      method: "post",
      data
  });
}

// 清空消息列表
export function repairRemindClearRq(data) {
  return request({
      url: `/app/repairRemind/clear`,
      method: "post",
      data
  });
}

// 返回订单状态
export function getStatusName(status) {
    // 状态:1 待派单,3 重新派单,5 已派单,7 处理中, 9已完成 待评价, 11 已关闭 13 已评价
    let statusList = [{
        status: 1,
        statusName: '待派单',
    }, {
        status: 3,
        statusName: '重新派单',
    }, {
        status: 5,
        statusName: '已派单',
    }, {
        status: 7,
        statusName: '处理中',
    }, {
        status: 9,
        statusName: '已完成',
    }, {
        status: 11,
        statusName: '已关闭',
    }, {
        status: 13,
        statusName: '已评价',
    }, ]
    //
    let obj = statusList.find(item => item.status == status)
    if (obj) {
        return obj.statusName
    } else {
        return '状态不存在!'
    }
}


// 返回查询订单状态
export function getQueryStatusName(status) {
    // 状态:1 处理中,3 重新派单,5 已派单,7 处理中, 9待评价, 11 无效单 13 已评价
    let statusList = [{
        status: 1,
        statusName: '处理中',
    }, {
        status: 3,
        statusName: '重新派单',
    }, {
        status: 5,
        statusName: '已派单',
    }, {
        status: 7,
        statusName: '处理中',
    }, {
        status: 9,
        statusName: '待评价',
    }, {
        status: 11,
        statusName: '无效单',
    }, {
        status: 13,
        statusName: '已评价',
    }, ]
    //
    let obj = statusList.find(item => item.status == status)
    if (obj) {
        return obj.statusName
    } else {
        return '状态不存在!'
    }
}