const app = getApp()

import Dialog from '@vant/weapp/dialog/dialog';
import Notify from '@vant/weapp/notify/notify';

import {
  selfFormatTimeYMD,
  selfFormatTimeHM,
  twoTimeIntervalReturnHours
} from "../../../../../utils/util.js"

import {
  selectReservationByIdRq,
  cancelOrderRq,
  inviteRecordPersonListRq,
  getMeetingRoomServiceAndEquipmentRq,
  approveOrderRq
} from "../../../../../api/meeting/meetingRoom.js"

Page({

  /**
   * 页面的初始数据
   */
  data: {
    IMG_NAME: app.IMG_NAME,
    id: null,
    detail: null,
    facilities: {},
    joinPersonList: [],
    showCancelReason: false, // 是否展示弹出层
    cancelId: '', // 取消预约会议id
    cancelReason: '', // 取消预约原因
    beforeClose(action) {
      return new Promise(resolve => {
        if (action === 'confirm') {
          resolve(false)
        } else {
          resolve(true)
        }
      });
    }, // 弹出层点击确认不关闭，手动关
    // 会议重新预约需要参数
    showEdit: false,
    editAction: [{
        name: '重新选择时间、会议室',
        type: 1
      },
      {
        name: '重新编辑会议信息',
        type: 2
      },
    ],
    timeShow: false,
    currentDate: new Date().getTime(),
    minDate: new Date().getTime(),
    maxDate: '',
    formatter(type, value) {
      if (type === 'year') {
        return `${value}年`;
      }
      if (type === 'month') {
        return `${value}月`;
      }
      if (type === 'day') {
        return `${value}日`;
      }
      return value;
    },
    // 驳回相关参数
    showRejectReason: false, // 是否展示弹出层
    rejectlId: '', // 驳回预约会议id
    rejectReason: '', // 驳回预约原因
    beforeReject(action) {
      return new Promise(resolve => {
        if (action === 'confirm') {
          resolve(false)
        } else {
          resolve(true)
        }
      });
    }, // 弹出层点击确认不关闭，手动关
    act: '' // 动作
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad(options) {
    let _this = this;
    _this.setData({
      ...options
    })
    // 获取详情
    _this.getDetail();
    // 获取一月后时间，默认只能选一个月之后
    const today = new Date()
    const newDate = new Date(today)
    newDate.setMonth(newDate.getMonth() + 1)
    _this.setData({
      maxDate: newDate.getTime()
    })
  },

  // 获取详情
  getDetail() {
    let _this = this;
    let id = _this.data.id;
    selectReservationByIdRq({
      id: id
    }).then(res => {
      console.log(res)
      let recordDetail = res.mr
      // let detail = res.data
      // 时间段
      recordDetail.timeSlot = selfFormatTimeYMD(recordDetail.start) + ' ' + selfFormatTimeHM(recordDetail.start) + '~' + selfFormatTimeHM(recordDetail.end);
      // 合计时间
      recordDetail.countTime = twoTimeIntervalReturnHours(recordDetail.start, recordDetail.end)
      // 状态字体颜色
      let statusColor = "#FFB119";
      // 按钮是否显示
      let statusValue = recordDetail.status;
      let showCancel = false // 显示取消操作
      let showEdit = false // 显示编辑操作
      let showSatff = false // 显示会务人员
      let showApprove = false // 显示审批操作
      let statusName = ''
      // 预约状态，1 取消  3 驳回 4 占用 5 待审核  7 审核通过，待开始 9 进行中 11已结束
      let act = _this.data.act
      
      if (statusValue == 1) {
        // 取消
        // 状态字体颜色
        if (act == '') {
          // 普通用户通过预约列表查看
          showEdit = true
        }
        statusColor = "#333333"
        statusName = '已取消'
      }
      if (statusValue == 3) {
        // 驳回，可以修改
        if (act == '') {
          // 普通用户通过预约列表查看
          showEdit = true
        }
        statusColor = "#333333"
        statusName = '已驳回'
      }
      if (statusValue == 4) {
        // 占用，管理员可以编辑
        if (act == 'approve') {
          // 管理员允许编辑
          showEdit = true
        }
        statusName = '已占用'
      }
      if (statusValue == 5) {
        // 待审核，普通用户只能取消，管理员可以修改
        if (_this.data.act == 'approve') {
          showEdit = true
          showApprove = true
          // showSatff = true
        } else {
          showCancel = true
        }
        // showEdit = true
        statusName = '待审核'
      }
      if (statusValue == 7) {
        // 审核通过，管理员可以修改、取消
        if (_this.data.act == 'approve') {
          showEdit = true
          showCancel = true
          showSatff = true
        }
        statusName = '待开始'
      }
      if (statusValue == 9) {
        // 进行中
        statusColor = "#333333"
        statusName = '进行中'
      }
      if (statusValue == 11) {
        // 已结束
        statusColor = "#333333"
        statusName = '已结束'
      }
      // 赋值
      recordDetail.showCancel = showCancel
      recordDetail.showEdit = showEdit
      recordDetail.showApprove = showApprove
      recordDetail.showSatff = showSatff
      recordDetail.statusName = statusName
      // 状态字体颜色
      recordDetail.statusColor = statusColor;
      let roomDetail = res.room
      recordDetail.room = roomDetail
      // 图片
      if (roomDetail.imgs) {
        try {
          recordDetail.room.indoorPicUrlFirst = roomDetail.imgs[0].url
        } catch (error) {
          console.log(`JSON error : ${error}`);
        }
      }
      let device = recordDetail.room.device
      // 处理设备
      device = device.replaceAll(' ', '')
      let deviceArr = device.split('#')
      // 删除第一个，第一个为空
      deviceArr.shift()
      recordDetail.roomDevice = deviceArr

      // 处理服务
      let serve = res.serve
      let serveArr = []
      for (let key in serve) {
        serveArr.push(serve[key].name)
      }
      recordDetail.serve = serveArr
      // 处理会务人员
      let staff = res.waiters
      let staffArr = {
        music: [],
        serve: []
      }
      for (let key in staff) {
        if (staff[key].type == '1') {
          // 音控组
          staffArr.music.push({
            name: staff[key].username,
            tel: staff[key].phone
          })
        } else if (staff[key].type == '3') {
          // 服务组
          staffArr.serve.push({
            name: staff[key].username,
            tel: staff[key].phone
          })
        }
      }
      recordDetail.staff = staffArr
      for (let key in recordDetail) {
        if (recordDetail[key] == null) {
          recordDetail[key] = ''
        }
      }
      _this.setData({
        detail: recordDetail
      })
    })
  },

  // 查询参与会议预约人员列表
  getInviteRecordPersonList() {
    let _this = this;
    let id = _this.data.id;
    inviteRecordPersonListRq(id).then(res => {
      console.log('inviteRecordPersonListRq', res);
      _this.setData({
        joinPersonList: res.data
      })
    })
  },
  pass(e) {
    let _this = this;
    let id = e.currentTarget.dataset.id
    Dialog.confirm({
        title: '确认',
        message: '是否确认通过会议室申请？',
      })
      .then(() => {
        // on confirm
        approveOrderRq({
          id: id,
          content: '审核通过',
          operate: 'PASS'
        }).then(res => {
          console.log('passOrder', res)
          if (res.code == 0) {
            Notify({
              type: 'success',
              message: '已通过该申请！'
            })
            // 刷新数据
            _this.getDetail()
            // 数据状态变更，向上个页面传递变更
            let pages = getCurrentPages() //获取page
            let prevPage = pages[pages.length - 2] //上一个页面（父页面）
            prevPage.setData({
              dataChange: true
            })
          } else {
            // 危险通知
            Notify({
              type: 'danger',
              message: res.msg
            });
          }
        })
      })
      .catch(() => {
        // on cancel
      });
  },
  // 驳回预约
  rejectConfirm(e) {
    console.log('rejectConfirm', e);
    let _this = this;
    let id = e.currentTarget.dataset.id
    _this.setData({
      rejectId: id,
      showRejectReason: true,
      rejectReason: ''
    })
  },
  onCloseReject(e) {
    let _this = this;
    _this.setData({
      rejectId: '',
      showRejectReason: false,
      rejectReason: ''
    })
  },
  onChangeRejectReason(e) {
    let _this = this;
    _this.setData({
      rejectReason: e.detail
    })
  },
  // 取消订单
  rejectOrder() {
    let _this = this;
    let id = _this.data.rejectId
    let reason = _this.data.rejectReason
    if (id === '') {
      return
    }
    if (reason === '') {
      Notify('请输入驳回原因！')
      return
    }
    // 执行驳回方法
    console.log('驳回，原因为' + reason)
    approveOrderRq({
      id: id,
      content: reason,
      operate: 'REJECTED'
    }).then(res => {
      console.log('rejectOrder', res);
      if (res.code == 0) {
        _this.setData({
          showRejectReason: false
        })
        Notify({
          type: 'danger',
          message: '已驳回该申请！'
        })
        // 刷新数据
        _this.getDetail()
        // 数据状态变更，向上个页面传递变更
        let pages = getCurrentPages() //获取page
        let prevPage = pages[pages.length - 2] //上一个页面（父页面）
        prevPage.setData({
          dataChange: true
        })
      } else {
        // 危险通知
        Notify({
          type: 'danger',
          message: res.msg
        })
      }
    })
  },
  // 取消预约一系列方法
  cancelConfirm(e) {
    console.log('cancelConfirm', e);
    let _this = this;
    let id = e.currentTarget.dataset.id
    _this.setData({
      cancelId: id,
      showCancelReason: true,
      cancelReason: ''
    })
  },
  onCloseCancel(e) {
    let _this = this;
    _this.setData({
      cancelId: '',
      showCancelReason: false,
      cancelReason: ''
    })
  },
  onChangeCancelReason(e) {
    let _this = this;
    _this.setData({
      cancelReason: e.detail
    })
  },
  // 取消订单
  cancelOrder() {
    let _this = this;
    let id = _this.data.cancelId
    let reason = _this.data.cancelReason
    if (id === '') {
      return
    }
    if (reason === '') {
      Notify('请输入取消原因！')
      return
    }
    cancelOrderRq({
      id: id,
      content: reason
    }).then(res => {
      console.log('cancelOrderRq', res);
      if (res.code == 0) {
        _this.setData({
          showCancelReason: false
        })
        // 刷新数据
        _this.getDetail();
        // 数据状态变更，向上个页面传递变更
        let pages = getCurrentPages(); //获取page
        let prevPage = pages[pages.length - 2]; //上一个页面（父页面）
        prevPage.setData({
          dataChange: true
        })
      } else {
        // 危险通知
        Notify({
          type: 'danger',
          message: res.msg
        });
      }
    })
  },
  editConfirm() {
    this.setData({
      showEdit: true
    })
  },
  hideEdit() {
    this.setData({
      showEdit: false
    })
  },
  editMode(e) {
    let _this = this
    if (e.detail.type === 1) {
      // 重选时间会议室
      this.setData({
        showEdit: false,
        timeShow: true
      })
    } else {
      // 直接跳转
      console.log('重新编辑会议基本信息！')
      this.setData({
        showEdit: false,
      })
      wx.navigateTo({
        url: "/pages/meeting/meetingRoom/meetingOrder/meetingOrder?rId=" + _this.data.detail.id,
      })
    }
  },
  showTimePicker() {
    this.setData({
      timeShow: true
    });
  },
  hideTimePicker() {
    this.setData({
      timeShow: false
    });
  },
  // 跳转会议预约页面
  goRes(e) {
    let _this = this
    let date = new Date(e.detail);
    let year = date.getFullYear()
    let month = date.getMonth() + 1
    let day = date.getDate()
    // IOS不支持-，必须用/
    let chooseTime = year + '/' + month + '/' + day + ' 00:00:00'
    let chooseTimeStr = new Date(chooseTime).getTime()
    // 加入rId参数，为预约id，用于重新修改
    wx.navigateTo({
      url: '/pages/meeting/meetingReservation/meetingReservation?rId=' + _this.data.detail.id + '&time=' + chooseTimeStr,
    })
  },

  // 跳转-支付
  jumpPay(e) {
    console.log('jumpPay', e);
    wx.navigateTo({
      url: "/pages/meeting/pay/waitPay/waitPay?id=" + e.currentTarget.dataset.id + "&type=meetingRoom"
    })
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady() {

  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow() {

  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide() {

  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload() {

  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh() {

  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom() {

  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage(e) {
    console.log('onShareAppMessage', e);
    let _this = this;
    let id = e.target.dataset.id;
    let detail = _this.data.detail
    //
    let param = {
      title: detail.title,
      path: "/pages/meeting/invite/invite?id=" + id,
      imageUrl: app.IMG_NAME + detail.room.indoorPicUrlFirst,
    }
    console.log('onShareAppMessage', param);
    return param;
  }
})